==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/23/23f8da902933d37362233e98589ecb58.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-fixed/assets/logo_demo-company-iii.svg */
class __TwigTemplate_ca737ababe92b631488912168a506138 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 343.3 52.1\" style=\"enable-background:new 0 0 343.3 52.1;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#4E5E9E;}
\t.st1{fill:#3F4C7F;}
</style>
<g>
\t<path class=\"st0\" d=\"M58.7,11.4c0-1.9,0.2-3.3,0.6-4.2c0.4-0.9,0.9-1.5,1.6-1.7c0.7-0.3,1.7-0.4,3.1-0.5V0H42.6h-0.1H21.4h-0.1H0
\t\tv5.7l5.6-0.2c-0.2,1.7-0.3,3.9-0.3,6.7v28.5c0,1.9-0.2,3.3-0.6,4.2c-0.4,0.9-0.9,1.5-1.6,1.7C2.4,47,1.3,47.1,0,47.2v4.9h21.3h0.1
\t\th21.2h0.1h21.3v-5.7c-2.1,0-4,0.1-5.6,0.2c0.2-1.7,0.3-3.9,0.3-6.7V11.4z M26.6,12.2v28.5c0,1.9-0.2,3.3-0.6,4.2
\t\tc-0.4,0.9-0.9,1.5-1.6,1.7c-0.7,0.3-1.7,0.4-3,0.5c0,0-4-0.7-5.6-0.6c0.2-1.7,0.3-3.9,0.3-6.7V11.4c0-1.9,0.2-3.3,0.6-4.2
\t\tc0.4-0.9,0.9-1.5,1.6-1.7C19,5.1,20,5,21.3,4.9l5.6,0.6C26.7,7.2,26.6,9.4,26.6,12.2z M47.9,12.2v28.5c0,1.9-0.2,3.3-0.6,4.2
\t\tc-0.4,0.9-0.9,1.5-1.6,1.7c-0.7,0.3-1.7,0.4-3,0.5c0,0-4-0.7-5.6-0.6c0.2-1.7,0.3-3.9,0.3-6.7V11.4c0-1.9,0.2-3.3,0.6-4.2
\t\tc0.4-0.9,0.9-1.5,1.6-1.7c0.7-0.3,1.7-0.4,3-0.5l5.6,0.6C48,7.2,47.9,9.4,47.9,12.2z\"/>
\t<g>
\t\t<path class=\"st1\" d=\"M110.6,37.4c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3v0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0c-0.7-0.7-1.8-0.9-2.6-0.3
\t\t\tC112.6,36.2,111.5,37,110.6,37.4z\"/>
\t\t<path class=\"st1\" d=\"M148.6,11.7c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C153.3,15.1,151.2,13.1,148.6,11.7z M150.8,32.3c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC152.5,28.3,152,30.4,150.8,32.3z\"/>
\t\t<path class=\"st1\" d=\"M183.3,32.6l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.3l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.1c0-1.8-1.5-3.3-3.3-3.3l0,0c-1.2,0-2.4,0.7-2.9,1.8L183.3,32.6z\"/>
\t\t<path class=\"st1\" d=\"M233.3,12.6c-2.2-1.9-5.4-2.9-9.4-2.9h-10.3c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C236.7,17.3,235.6,14.6,233.3,12.6z M230.2,26.3
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V13.8l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C232.4,23.2,231.6,25.1,230.2,26.3z\"/>
\t\t<path class=\"st1\" d=\"M252.3,11.9l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3l0,0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C254.2,9.8,252.9,10.6,252.3,11.9z
\t\t\t M249.6,28.2l5.8-13.6l5.9,13.6H249.6z\"/>
\t\t<path class=\"st1\" d=\"M302.8,35l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7h-0.2c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.1l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35z\"/>
\t\t<path class=\"st1\" d=\"M339.6,10.8l-9.3,16.6l-9.5-16.6c-0.4-0.6-1-1-1.7-1h0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6V40
\t\t\tc0,1.2,1,2.2,2.2,2.2l0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C340.6,9.8,339.9,10.2,339.6,10.8z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-fixed/assets/logo_demo-company-iii.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-fixed/assets/logo_demo-company-iii.svg", "/var/www/mautic-ktn/themes/fresh-fixed/assets/logo_demo-company-iii.svg");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/23/23f8da902933d37362233e98589ecb58.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-fixed/assets/logo_demo-company-iii.svg */
class __TwigTemplate_ca737ababe92b631488912168a506138 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 343.3 52.1\" style=\"enable-background:new 0 0 343.3 52.1;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#4E5E9E;}
\t.st1{fill:#3F4C7F;}
</style>
<g>
\t<path class=\"st0\" d=\"M58.7,11.4c0-1.9,0.2-3.3,0.6-4.2c0.4-0.9,0.9-1.5,1.6-1.7c0.7-0.3,1.7-0.4,3.1-0.5V0H42.6h-0.1H21.4h-0.1H0
\t\tv5.7l5.6-0.2c-0.2,1.7-0.3,3.9-0.3,6.7v28.5c0,1.9-0.2,3.3-0.6,4.2c-0.4,0.9-0.9,1.5-1.6,1.7C2.4,47,1.3,47.1,0,47.2v4.9h21.3h0.1
\t\th21.2h0.1h21.3v-5.7c-2.1,0-4,0.1-5.6,0.2c0.2-1.7,0.3-3.9,0.3-6.7V11.4z M26.6,12.2v28.5c0,1.9-0.2,3.3-0.6,4.2
\t\tc-0.4,0.9-0.9,1.5-1.6,1.7c-0.7,0.3-1.7,0.4-3,0.5c0,0-4-0.7-5.6-0.6c0.2-1.7,0.3-3.9,0.3-6.7V11.4c0-1.9,0.2-3.3,0.6-4.2
\t\tc0.4-0.9,0.9-1.5,1.6-1.7C19,5.1,20,5,21.3,4.9l5.6,0.6C26.7,7.2,26.6,9.4,26.6,12.2z M47.9,12.2v28.5c0,1.9-0.2,3.3-0.6,4.2
\t\tc-0.4,0.9-0.9,1.5-1.6,1.7c-0.7,0.3-1.7,0.4-3,0.5c0,0-4-0.7-5.6-0.6c0.2-1.7,0.3-3.9,0.3-6.7V11.4c0-1.9,0.2-3.3,0.6-4.2
\t\tc0.4-0.9,0.9-1.5,1.6-1.7c0.7-0.3,1.7-0.4,3-0.5l5.6,0.6C48,7.2,47.9,9.4,47.9,12.2z\"/>
\t<g>
\t\t<path class=\"st1\" d=\"M110.6,37.4c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3v0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0c-0.7-0.7-1.8-0.9-2.6-0.3
\t\t\tC112.6,36.2,111.5,37,110.6,37.4z\"/>
\t\t<path class=\"st1\" d=\"M148.6,11.7c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C153.3,15.1,151.2,13.1,148.6,11.7z M150.8,32.3c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC152.5,28.3,152,30.4,150.8,32.3z\"/>
\t\t<path class=\"st1\" d=\"M183.3,32.6l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.3l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.1c0-1.8-1.5-3.3-3.3-3.3l0,0c-1.2,0-2.4,0.7-2.9,1.8L183.3,32.6z\"/>
\t\t<path class=\"st1\" d=\"M233.3,12.6c-2.2-1.9-5.4-2.9-9.4-2.9h-10.3c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C236.7,17.3,235.6,14.6,233.3,12.6z M230.2,26.3
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V13.8l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C232.4,23.2,231.6,25.1,230.2,26.3z\"/>
\t\t<path class=\"st1\" d=\"M252.3,11.9l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3l0,0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C254.2,9.8,252.9,10.6,252.3,11.9z
\t\t\t M249.6,28.2l5.8-13.6l5.9,13.6H249.6z\"/>
\t\t<path class=\"st1\" d=\"M302.8,35l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7h-0.2c-1.2,0-2.2,1-2.2,2.2V40c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.1l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35z\"/>
\t\t<path class=\"st1\" d=\"M339.6,10.8l-9.3,16.6l-9.5-16.6c-0.4-0.6-1-1-1.7-1h0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6V40
\t\t\tc0,1.2,1,2.2,2.2,2.2l0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C340.6,9.8,339.9,10.2,339.6,10.8z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-fixed/assets/logo_demo-company-iii.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-fixed/assets/logo_demo-company-iii.svg", "/var/www/html/mauticGIT-Test/themes/fresh-fixed/assets/logo_demo-company-iii.svg");
    }
}
